A ^_^ cat who use Plato Service

Install

```
pip install plato-cat
```

Run

```
/usr/bin/plato-cat --endpoint ENDPOINT --key ACCESS_KEY --secret ACCESS_SECRET
/usr/bin/plato-clean --endpoint ENDPOINT --key ACCESS_KEY --secret ACCESS_SECRET

or with config file

/usr/bin/plato-cat --config-file YOUR_CONFIG_FILE_PATH
/usr/bin/plato-clean --config-file YOUR_CONFIG_FILE_PATH

check cat.conf.sample for example.

```
